from . import skkdictutils

__all__ = ['parse_skkdict', 'merge_skkdict', 'ari2nasi', 'write_skkdict', 'expand_okuri']

__version__ = '0.1.0'

parse_skkdict = skkdictutils.parse_skkdict
merge_skkdict = skkdictutils.merge_skkdict
ari2nasi = skkdictutils.ari2nasi
write_skkdict = skkdictutils.write_skkdict
expand_okuri = skkdictutils.expand_okuri
